@@ -52,7 +52,7 @@ from xarray import DataArray, Dataset, register_dataarray_accessor, register_dat
 
 from xarray_plotly import config
 from xarray_plotly.accessor import DataArrayPlotlyAccessor, DatasetPlotlyAccessor
-from xarray_plotly.common import SLOT_ORDERS, auto
+from xarray_plotly.common import SLOT_ORDERS, Colors, auto
 from xarray_plotly.figures import (
     add_secondary_y,
     overlay,
@@ -61,6 +61,7 @@ from xarray_plotly.figures import (
 
 __all__ = [
     "SLOT_ORDERS",
+    "Colors",
     "add_secondary_y",
     "auto",
     "config",
@@ -110,5 +111,5 @@ def xpx(data: DataArray | Dataset) -> DataArrayPlotlyAccessor | DatasetPlotlyAcc
 __version__ = version("xarray_plotly")
 
 # Register the accessors
-register_dataarray_accessor("plotly")(DataArrayPlotlyAccessor)
-register_dataset_accessor("plotly")(DatasetPlotlyAccessor)
+register_dataarray_accessor("plotly")(DataArrayPlotlyAccessor)  # type: ignore[no-untyped-call]
+register_dataset_accessor("plotly")(DatasetPlotlyAccessor)  # type: ignore[no-untyped-call]
